==> opm-simulators_2025.04+ds.orig.tar.xz: opm-simulators-release-2025.04-final/examples/co2_ptflash_ecfv.cpp <==
// -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
// vi: set et ts=4 sw=4 sts=4:
/*
  This file is part of the Open Porous Media project (OPM).

  OPM is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  OPM is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with OPM.  If not, see <http://www.gnu.org/licenses/>.

  Consult the COPYING file in the top-level source directory of this
  module for the precise wording of the license and the list of
  copyright holders.
*/
/*!
 * \file
 *
 * \brief Box problem with two phases and multiple components.
 *        Solved with a PTFlash two phase solver.
 */
#include "config.h"

#include <opm/models/utils/start.hh>
#include "problems/co2ptflashproblem.hh"


namespace Opm::Properties {

namespace TTag {
    struct CO2PTEcfvProblem {
    using InheritsFrom = std::tuple<CO2PTBaseProblem, FlashModel>;
};
}

template <class TypeTag>
struct SpatialDiscretizationSplice<TypeTag, TTag::CO2PTEcfvProblem>
{
    using type = TTag::EcfvDiscretization;
};

template <class TypeTag>
struct LocalLinearizerSplice<TypeTag, TTag::CO2PTEcfvProblem>
{
    using type = TTag::AutoDiffLocalLinearizer;
};


} // namespace Opm::Properties

int main(int argc, char **argv)
{
    using EcfvProblemTypeTag = Opm::Properties::TTag::CO2PTEcfvProblem;
    return Opm::start<EcfvProblemTypeTag>(argc, argv);
}

==> opm-simulators_2025.10+ds.orig.tar.xz: opm-simulators-release-2025.10-final/examples/co2_ptflash_ecfv.cpp <==
// -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
// vi: set et ts=4 sw=4 sts=4:
/*
  This file is part of the Open Porous Media project (OPM).

  OPM is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  OPM is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with OPM.  If not, see <http://www.gnu.org/licenses/>.

  Consult the COPYING file in the top-level source directory of this
  module for the precise wording of the license and the list of
  copyright holders.
*/
/*!
 * \file
 *
 * \brief Box problem with two phases and multiple components.
 *        Solved with a PTFlash two phase solver.
 */
#include "config.h"

#include <opm/models/utils/start.hh>
#include "problems/co2ptflashproblem.hh"


namespace Opm::Properties {

namespace TTag {
    struct CO2PTEcfvProblem {
    using InheritsFrom = std::tuple<CO2PTBaseProblem, FlashModel>;
};
}

template <class TypeTag>
struct SpatialDiscretizationSplice<TypeTag, TTag::CO2PTEcfvProblem>
{
    using type = TTag::EcfvDiscretization;
};

template <class TypeTag>
struct LocalLinearizerSplice<TypeTag, TTag::CO2PTEcfvProblem>
{
    using type = TTag::AutoDiffLocalLinearizer;
};


} // namespace Opm::Properties

int main(int argc, char **argv)
{
    using EcfvProblemTypeTag = Opm::Properties::TTag::CO2PTEcfvProblem;
    return Opm::start<EcfvProblemTypeTag>(argc, argv, true);
}
